%define         pkgname    gnupg

Summary:	GNU privacy guard - a free PGP replacement
Name:		gnupg2
Version:	2.4.5
Release:	%mkrel 1
License:	GPLv3+
Group:		File tools
URL:		https://www.gnupg.org
Source0:	https://gnupg.org/ftp/gcrypt/gnupg/gnupg-%{version}.tar.bz2
Source1:	https://gnupg.org/ftp/gcrypt/gnupg/gnupg-%{version}.tar.bz2.sig
Patch0:		gnupg-1.9.3-use-ImageMagick-for-photo.patch
# Mostly reverts https://dev.gnupg.org/rGeae28f1bd4a5632e8f8e85b7248d1c4d4a10a5ed
Patch33:	gnupg-2.4.3-restore-systemd-sockets.patch

BuildRequires:	docbook-utils
BuildRequires:	sendmail-command
BuildRequires:	npth-devel
BuildRequires:	pkgconfig(ldap)
BuildRequires:	pkgconfig(gpg-error) >= 1.11
BuildRequires:	pkgconfig(libgcrypt) >= 1.9.1
BuildRequires:	pkgconfig(libassuan) >= 2.0.0
BuildRequires:	pkgconfig(ksba) >= 1.0.7
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libusb)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(tss2-esys)

Recommends:	pinentry

# dirmngr is now part of gnupg2
Provides:	dirmngr = %{version}-%{release}
Obsoletes:	dirmngr < 1.2.0-1

Obsoletes:	gnupg2 < 2.2.11-3
Obsoletes:	gnupg < 1.4.23-3
Provides:	gnupg = %{version}-%{release}


%description
GnuPG is GNU's tool for secure communication and data storage.
It can be used to encrypt data and to create digital signatures.
It includes an advanced key management facility and is compliant
with the proposed OpenPGP Internet standard as described in RFC2440.

%prep
%autosetup -p1 -n %{pkgname}-%{version}

%build
%serverbuild

# Add libassuan headers to search path
CPATH=%{_includedir}:%{_includedir}/libassuan2
export CPATH

%configure \
	--libexecdir=%{_libexecdir}/gnupg2 \
	--enable-g13 \
	--disable-rpath \
	--with-tss=intel \
	--without-capabilities

%make_build

# all tests must pass on i586 and x86_64
%check
# need scratch gpg database for tests
mkdir -p $HOME/.gnupg
[[ -n "$GPG_AGENT_INFO" ]] || eval `./agent/gpg-agent --use-standard-socket --daemon --write-env-file gpg-agent-info`
make check
[[ -a gpg-agent-info ]] && kill -0 `cut -d: -f 2 gpg-agent-info`
rm -f gpg-agent-info

%install
%make_install \
  docdir=%{_pkgdocdir}

# gpgconf.conf
%__install -d %{buildroot}%{_sysconfdir}/gnupg
touch %{buildroot}%{_sysconfdir}/gnupg/gpgconf.conf

ln -s gpg %{buildroot}%{_bindir}/gpg2
ln -s gpgv %{buildroot}%{_bindir}/gpgv2
ln -s gpg.1 %{buildroot}%{_mandir}/man1/gpg2.1
ln -s gpgv.1 %{buildroot}%{_mandir}/man1/gpgv2.1
ln -s gnupg.7 %{buildroot}%{_mandir}/man7/gnupg2.7

# Move the systemd user units to appropriate directory
install -d -m755 %{buildroot}%{_userunitdir}
mv %{buildroot}%{_pkgdocdir}/examples/systemd-user/*.socket %{buildroot}%{_userunitdir}
mv %{buildroot}%{_pkgdocdir}/examples/systemd-user/*.service %{buildroot}%{_userunitdir}

%find_lang %{name}

%files -f %{name}.lang
%doc NEWS THANKS TODO ChangeLog
%doc %{_pkgdocdir}/*
%dir %{_sysconfdir}/gnupg
%ghost %config(noreplace) %{_sysconfdir}/gnupg/gpgconf.conf
%attr(4755,root,root) %{_bindir}/gpgsm
%{_bindir}/gpg-agent
%{_bindir}/gpg-card
%{_bindir}/gpg-wks-client
%{_bindir}/gpgconf
%{_bindir}/kbxutil
%{_bindir}/watchgnupg
%{_bindir}/gpg-connect-agent
%{_bindir}/gpgparsemail
%{_bindir}/gpg
%{_bindir}/gpg2
%{_bindir}/gpgv
%{_bindir}/gpgv2
%{_bindir}/dirmngr
%{_bindir}/dirmngr-client
%{_bindir}/g13
%{_bindir}/gpgscm
%{_bindir}/gpgsplit
%{_bindir}/gpgtar
%{_bindir}/gpg-wks-server
%{_sbindir}/addgnupghome
%{_sbindir}/applygnupgdefaults
%{_sbindir}/g13-syshelp
%{_datadir}/gnupg/
%dir %{_libexecdir}/gnupg2
%{_libexecdir}/gnupg2/gpg-auth
%{_libexecdir}/gnupg2/gpg-check-pattern
%{_libexecdir}/gnupg2/gpg-preset-passphrase
%{_libexecdir}/gnupg2/gpg-protect-tool
%{_libexecdir}/gnupg2/scdaemon
%{_libexecdir}/gnupg2/dirmngr_ldap
%{_libexecdir}/gnupg2/gpg-wks-client
%{_libexecdir}/gnupg2/gpg-pair-tool   
%{_libexecdir}/gnupg2/keyboxd
%{_libexecdir}/gnupg2/tpm2daemon
%{_infodir}/gnupg.info*
%{_mandir}/man?/*
%{_userunitdir}/*


%changelog
* Thu Mar 07 2024 kekepower <kekepower> 2.4.5-1.mga10
+ Revision: 2048451
- Update to version 2.4.5

* Mon Jan 29 2024 kekepower <kekepower> 2.4.4-1.mga10
+ Revision: 2036106
- Update to version 2.4.4

* Thu Dec 07 2023 daviddavid <daviddavid> 2.4.3-1.mga10
+ Revision: 2014823
- new version: 2.4.3

* Fri Oct 14 2022 luigiwalser <luigiwalser> 2.3.8-1.mga9
+ Revision: 1896841
- 2.3.8

* Sun Sep 04 2022 kekepower <kekepower> 2.3.7-1.mga9
+ Revision: 1883761
- Update to version 2.3.7 to fix CVE-2022-34903 (mga#30591)

* Mon Apr 25 2022 kekepower <kekepower> 2.3.6-1.mga9
+ Revision: 1853717
- Update to version 2.3.6

* Fri Apr 22 2022 kekepower <kekepower> 2.3.5-1.mga9
+ Revision: 1852574
- Update to version 2.3.5

* Wed Mar 30 2022 umeabot <umeabot> 2.3.4-2.mga9
+ Revision: 1833745
- Mageia 9 Mass Rebuild

* Tue Dec 21 2021 kekepower <kekepower> 2.3.4-1.mga9
+ Revision: 1763072
- Update to version 2.3.4

* Wed Oct 13 2021 kekepower <kekepower> 2.3.3-1.mga9
+ Revision: 1751174
- Update to version 2.3.3

* Wed Aug 25 2021 kekepower <kekepower> 2.3.2-1.mga9
+ Revision: 1742542
- Update to version 2.3.2

* Wed Apr 21 2021 kekepower <kekepower> 2.3.1-1.mga9
+ Revision: 1717814
- Update to version 2.3.1

* Sat Mar 06 2021 neoclust <neoclust> 2.2.27-3.mga9
+ Revision: 1700260
- Rebuild because of missing signatures

* Sat Mar 06 2021 wally <wally> 2.2.27-2.mga9
+ Revision: 1700245
- don't remove /usr/share/gnupg/ during the build as /usr/share/gnupg/sks-keyservers.netCA.pem is needed by dirmngr
- drop unused config file

* Mon Jan 11 2021 luigiwalser <luigiwalser> 2.2.27-1.mga8
+ Revision: 1671209
- 2.2.27

* Tue Dec 22 2020 kekepower <kekepower> 2.2.26-1.mga8
+ Revision: 1662695
- Update to version 2.2.26

* Mon Dec 07 2020 joequant <joequant> 2.2.25-2.mga8
+ Revision: 1654247
- move activation to user to avoid needing systemd

* Tue Nov 24 2020 kekepower <kekepower> 2.2.25-1.mga8
+ Revision: 1648893
- Update to version 2.2.25

* Tue Nov 17 2020 kekepower <kekepower> 2.2.24-1.mga8
+ Revision: 1646859
- Update to version 2.2.24

* Thu Sep 03 2020 kekepower <kekepower> 2.2.23-1.mga8
+ Revision: 1621443
- Update to version 2.2.23

* Fri Aug 28 2020 luigiwalser <luigiwalser> 2.2.22-1.mga8
+ Revision: 1619281
- 2.2.22

* Fri Jul 10 2020 kekepower <kekepower> 2.2.21-1.mga8
+ Revision: 1604014
- Update to version 2.2.21

* Sun Apr 19 2020 wally <wally> 2.2.20-3.mga8
+ Revision: 1569871
- drop empty postun scriptlet
- fix preun and postun scriptlets

* Sun Apr 19 2020 joequant <joequant> 2.2.20-2.mga8
+ Revision: 1569802
- rebuild to remove info-install dependency

* Fri Mar 20 2020 kekepower <kekepower> 2.2.20-1.mga8
+ Revision: 1558414
- Update to version 2.2.20

* Tue Feb 18 2020 umeabot <umeabot> 2.2.19-3.mga8
+ Revision: 1542165
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 2.2.19-2.mga8
+ Revision: 1475957
- rebuild for readline

* Sat Dec 07 2019 kekepower <kekepower> 2.2.19-1.mga8
+ Revision: 1464990
- Update to version 2.2.19

* Tue Nov 26 2019 kekepower <kekepower> 2.2.18-1.mga8
+ Revision: 1462876
- Update to version 2.2.18

* Tue Jul 09 2019 kekepower <kekepower> 2.2.17-1.mga8
+ Revision: 1419758
- Update to version 2.2.17
- Rediff Patch0

* Tue Mar 26 2019 kekepower <kekepower> 2.2.15-1.mga7
+ Revision: 1380434
- Update to version 2.2.15

* Tue Mar 19 2019 kekepower <kekepower> 2.2.14-1.mga7
+ Revision: 1378852
- Update to version 2.2.14

* Tue Feb 12 2019 kekepower <kekepower> 2.2.13-1.mga7
+ Revision: 1366186
- Update to version 2.2.13

* Sun Feb 03 2019 wally <wally> 2.2.12-3.mga7
+ Revision: 1362889
- provide ghost global config file /etc/gnupg/gpgconf.conf

* Fri Dec 28 2018 kekepower <kekepower> 2.2.12-2.mga7
+ Revision: 1345804
- gnupg2 now provides gpg and gpg2, replacing gnupg (mga#22958)
- Obsolete gnupg 1.4.x

* Tue Dec 25 2018 wally <wally> 2.2.12-1.mga7
+ Revision: 1344979
- new version 2.2.12

* Mon Nov 26 2018 tv <tv> 2.2.11-2.mga7
+ Revision: 1335260
- recommends instead of requires pinentry (mga#23894)

* Tue Nov 06 2018 kekepower <kekepower> 2.2.11-1.mga7
+ Revision: 1328675
- Update to version 2.2.11

* Mon Sep 03 2018 tv <tv> 2.2.10-2.mga7
+ Revision: 1256559
- need scratch gpg database for tests
- rely on filetriggers for info system (mga#23482)

* Sat Sep 01 2018 kekepower <kekepower> 2.2.10-1.mga7
+ Revision: 1256004
- Update to version 2.2.10

* Wed Jun 13 2018 kekepower <kekepower> 2.2.8-1.mga7
+ Revision: 1236723
- Update to version 2.2.8

* Mon May 07 2018 wally <wally> 2.2.7-2.mga7
+ Revision: 1227558
- drop unneeded --version hacks

* Sat May 05 2018 kekepower <kekepower> 2.2.7-1.mga7
+ Revision: 1226253
- Update to version 2.2.7

* Mon Apr 23 2018 wally <wally> 2.2.6-2.mga7
+ Revision: 1221818
- build with --enable-gpg-is-gpg2

* Wed Apr 11 2018 kekepower <kekepower> 2.2.6-1.mga7
+ Revision: 1217464
- Update to version 2.2.6

* Wed Mar 28 2018 kekepower <kekepower> 2.2.5-1.mga7
+ Revision: 1213060
- Update to version 2.2.5
- Fixed file list

* Mon Feb 26 2018 daviddavid <daviddavid> 2.1.22-3.mga7
+ Revision: 1205277
- remove no more needed BR libpth-devel

* Tue Jan 02 2018 wally <wally> 2.1.22-2.mga7
+ Revision: 1189322
- rebuild for new readline

* Sat Jul 29 2017 luigiwalser <luigiwalser> 2.1.22-1.mga7
+ Revision: 1132497
- 2.1.22
- rediff patch 100
- remove upstream patch 101

* Mon Jun 19 2017 ngompa <ngompa> 2.1.21-2.mga6
+ Revision: 1107904
- Add patch to fix tests requiring scdaemon
+ buchan <buchan>
- Dont run autogen.sh, so we dont get warning about development version
- Patch autogen.sh so even if we run it, we indicate its not
  a development version but indicate the RPM release in the version

* Tue May 16 2017 luigiwalser <luigiwalser> 2.1.21-1.mga6
+ Revision: 1101859
- 2.1.21
- remove upstreamed libdns patch

* Tue May 02 2017 eatdirt <eatdirt> 2.1.20-2.mga6
+ Revision: 1098635
- Remove obsoleted option --use-standard-socket

* Sat Apr 29 2017 luigiwalser <luigiwalser> 2.1.20-1.mga6
+ Revision: 1097989
- 2.1.20
- update build patch from fedora
- add patch from fedora to fix libdns aliasing issues
- 2.1.19

* Tue Jan 24 2017 luigiwalser <luigiwalser> 2.1.18-1.mga6
+ Revision: 1083265
- 2.1.18

* Thu Dec 22 2016 ngompa <ngompa> 2.1.17-2.mga6
+ Revision: 1076438
- Add patch from Fedora to fix builds on 32-bit arches
- Upgrade to 2.1.17
- Obsolete dirmngr, as it's now part of gnupg2
- Downgrade gnupg Requires to Recommends, as gnupg2 doesn't need it

* Fri Nov 18 2016 eatdirt <eatdirt> 2.0.30-4.mga6
+ Revision: 1068183
- Disable --keep-display option (mga#19391)

* Wed Jun 01 2016 eatdirt <eatdirt> 2.0.30-3.mga6
+ Revision: 1019722
- Migrate to systemd user service (mga#14627)

* Mon Apr 18 2016 luigiwalser <luigiwalser> 2.0.30-1.mga6
+ Revision: 1003506
- 2.0.30

* Thu Feb 11 2016 umeabot <umeabot> 2.0.29-3.mga6
+ Revision: 954135
- Mageia 6 Mass Rebuild

* Sat Oct 17 2015 fwang <fwang> 2.0.29-2.mga6
+ Revision: 892313
- use libexecdir

* Sat Oct 17 2015 fwang <fwang> 2.0.29-1.mga6
+ Revision: 892307
- add sig
- 2.0.29
+ ycantin <ycantin>
- new version 2.1.8
  use npth and gnutls
  fix user uid >= 1000
  Obsoletes dirmngr
  removed gpgsm-gencert.sh gnupg-pcsc-wrapper gpg2keys_* (deprecated)

* Thu Sep 10 2015 fwang <fwang> 2.0.28-2.mga6
+ Revision: 875418
- rebuild for new libgcrypt

* Sun Sep 06 2015 wally <wally> 2.0.28-1.mga6
+ Revision: 873203
- new version 2.0.28

* Fri Mar 06 2015 luigiwalser <luigiwalser> 2.0.27-1.mga5
+ Revision: 817954
- 2.0.27

* Wed Oct 15 2014 umeabot <umeabot> 2.0.26-3.mga5
+ Revision: 740298
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.26-2.mga5
+ Revision: 679829
- Mageia 5 Mass Rebuild

* Wed Aug 13 2014 luigiwalser <luigiwalser> 2.0.26-1.mga5
+ Revision: 662232
- 2.0.26

* Sat Jul 05 2014 pterjan <pterjan> 2.0.25-2.mga5
+ Revision: 643612
- Replace libusb*-devel BuildRequires by better ones

* Tue Jul 01 2014 luigiwalser <luigiwalser> 2.0.25-1.mga5
+ Revision: 641772
- 2.0.25

* Tue Jun 24 2014 luigiwalser <luigiwalser> 2.0.24-1.mga5
+ Revision: 639320
- 2.0.24

* Tue Jun 03 2014 luigiwalser <luigiwalser> 2.0.23-1.mga5
+ Revision: 632606
- 2.0.23

* Thu Jan 09 2014 dmorgan <dmorgan> 2.0.22-3.mga4
+ Revision: 565758
- Rebuild to please autobuild

* Mon Oct 21 2013 umeabot <umeabot> 2.0.22-2.mga4
+ Revision: 539521
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 fwang <fwang> 2.0.22-1.mga4
+ Revision: 492375
- new version 2.0.22

* Mon Sep 30 2013 oden <oden> 2.0.21-2.mga4
+ Revision: 489449
- P1: security fix for CVE-2013-4351 (opensuse)

* Tue Aug 20 2013 fwang <fwang> 2.0.21-1.mga4
+ Revision: 468236
- new version 2.0.21

* Thu Jun 27 2013 fwang <fwang> 2.0.20-1.mga4
+ Revision: 447354
- update file list
- update file list
- new version 2.0.20

* Sat Jan 12 2013 umeabot <umeabot> 2.0.19-3.mga3
+ Revision: 352373
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 oden <oden> 2.0.19-2.mga3
+ Revision: 337608
- P2: security fix for CVE-2012-6085 (upstream)

* Thu Jul 12 2012 solbu <solbu> 2.0.19-1.mga3
+ Revision: 269615
- Fix License tag
- Remove 8-years old obsolete
- New version

* Fri Jun 22 2012 boklm <boklm> 2.0.18-2.mga3
+ Revision: 262622
- remove test on non-empty /etc/mtab file (from Dave Hodgins, fixing bug #5360)

* Fri Aug 05 2011 fwang <fwang> 2.0.18-1.mga2
+ Revision: 131851
- new version 2.0.18
- new version 2.0.17

* Sat Jan 15 2011 mikala <mikala> 2.0.16-6.mga1
+ Revision: 18603
- imported package gnupg2

